@@ -136,6 +136,8 @@ class mysql(object):
 	def _decide_type(self,value):
 		if isinstance(value,(int,float)):
 			pass
+		elif isinstance(value,bytes):
+			value=value.decode('utf-8')
 		elif value is None:
 			value='NULL'
 		else:
